function TextRecognition(newImage)
    %TextRecognition accepts a cropped image of a license plate and outputs 
    %the numbers and letters of the plate to the console. It keeps these
    %final values in the variable noPlate. 
    
    %In its current state it is meant to be called from
    %VerticalEdgeDetection.m

    %I = imread('newImg.jpg');
    I = newImage;
    %grayImage = rgb2gray(I);
    level = graythresh(I);
    BW = im2bw(I,level);
    BW = imcomplement(BW);
    [height width] = size(BW);
    minscaled = round(0.3*height); %Assume letters are at least 30% the size of the image height
    maxscaled = round(0.8*height); %Assume letters are less than 80% of the image height
    %figure();
    %imshow(BW); title('1:Grayscale');
    
    
    CC = bwconncomp(BW); %find connected components
    
    stats = regionprops(CC,'BoundingBox', 'Eccentricity', ...
        'Solidity', 'FilledArea', 'Extent', 'Euler', 'Image', 'Orientation');
    
    filterIdx = [stats.FilledArea] < 20;
    %filterIdx = filterIdx | [stats.Eccentricity] < .995;
    %filterIdx = filterIdx | [stats.Extent] > .95;
    filterIdx = filterIdx | ([stats.Orientation] > -80 & [stats.Orientation] < 80);
    stats(filterIdx) = [];
    
    bboxes = vertcat(stats.BoundingBox);
    newbboxes = zeros(1,4);
    r = [];
    for j = 1:size(bboxes,1)
            left = bboxes(j,1);
            top = bboxes(j,2);
            width = bboxes(j,3);
            height = bboxes(j,4);
            if (height > minscaled && height < maxscaled)
                newbboxes(j,:) = bboxes(j,:);
                r = [r j];
            end 
    end
    
    %newbboxes
    
    % Convert from the [x y width height] bounding box format to the [xmin ymin
    % xmax ymax] format for convenience.
    xmin = newbboxes(:,1);
    ymin = newbboxes(:,2);
    xmax = xmin + newbboxes(:,3) - 1;
    ymax = ymin + newbboxes(:,4) - 1;
    
    BBoxes = [xmin ymin xmax-xmin+1 ymax-ymin+1];
    DrawBBoxes = insertShape(I,'Rectangle',BBoxes,'LineWidth',3);
%     figure();
%     imshow(DrawBBoxes)
%     title('Bounding Boxes Text')
    Images = {stats.Image};

if ~isempty(r) % If succesfully indices of desired boxes are achieved.
    noPlate=[]; % Initializing the variable of number plate string.
    for v=1:length(r)
        N=Images{1,r(v)}; % Extracting the binary image corresponding to the indices in 'r'.
        letter=readLetter(N); % Reading the letter corresponding the binary image 'N'.
        noPlate=[noPlate letter]; % Appending every subsequent character in noPlate variable.
    end
    noPlate;
        if size(noPlate,2) >= 6
            breakdown = isletter(noPlate);
            lefthalf = breakdown(1) + breakdown(2) + breakdown(3);
            righthalf = breakdown(4) + breakdown(5) + breakdown(6);
            
            if lefthalf >= 2 %then likely are letters on the left side
                for i = 1:3
                     if noPlate(i)=='0', noPlate(i) = 'O'; end
                     if noPlate(i)=='3', noPlate(i) = 'B'; end
                     if noPlate(i)=='1', noPlate(i) = 'I'; end
                     if noPlate(i)=='2', noPlate(i) = 'Z'; end
                end
            end 
            
            if righthalf >= 2 %then likely there are letters on the right side
                for i = 4:size(noPlate,2)
                     if noPlate(i)=='0', noPlate(i) = 'O'; end
                     if noPlate(i)=='3', noPlate(i) = 'B'; end
                     if noPlate(i)=='1', noPlate(i) = 'I'; end
                     if noPlate(i)=='2', noPlate(i) = 'Z'; end
                end
            end
            
            if lefthalf <=1 %then likely are numbers on the left side
                for i = 1:3
                     if noPlate(i)=='O', noPlate(i) = '0'; end
                     if noPlate(i)=='B', noPlate(i) = '3'; end
                     if noPlate(i)=='I', noPlate(i) = '1'; end
                     if noPlate(i)=='Z', noPlate(i) = '2'; end
                     if noPlate(i)=='D', noPlate(i) = '0'; end
                     if noPlate(i)=='P', noPlate(i) = '2'; end
                end
            end 
            
            if righthalf <=1 %then likely are numbers on the left side
                for i = 4:size(noPlate,2)
                     if noPlate(i)=='O', noPlate(i) = '0'; end
                     if noPlate(i)=='B', noPlate(i) = '3'; end
                     if noPlate(i)=='I', noPlate(i) = '1'; end
                     if noPlate(i)=='Z', noPlate(i) = '2'; end
                     if noPlate(i)=='D', noPlate(i) = '0'; end
                     if noPlate(i)=='P', noPlate(i) = '2'; end
                end            
            end 
        end 

    CheckOutput = ['output ' noPlate]
    noPlate;
    
else % If fail to extract the indexes in 'r' this line of error will be displayed.
    fprintf('Unable to extract the characters from the number plate.\n');
    fprintf('The characters on the number plate might not be clear or touching with each other or boundries.\n');
end
    
    %figure(), imshow(I); title('Text Recognition');    
    %h = drawrectangle;
    %position = h.Position
    
    %ATTEMPT WITH OCR. ITS NOT GREAT.
%     BBoxes( ~any(BBoxes,2), : ) = [];  %rows
%     BBoxes( :, ~any(BBoxes,1) ) = [];  %columns
%     ocrtxt = ocr(I,BBoxes);
%     [ocrtxt.Text]
end 