function VerticalEdgeDetection(num)
    %VerticalEdgeDetection Uses the number of the image file (num), to
    %output the license plate letters and numbers from the image.
    
    %In its current state it is meant to be run from testScript.m.
   
    file = ['Test_Images\Plate(' num2str(num) ').jpg'];
    I = imread(file);
    
    %Resize to make the calculation quicker, and more consistent for many
    %pictures
    I = imresize(I, [655 1000]);
    
%    Histogram Equalization to increase contrast. Abandoned. Did not Help.
%    J = histeq(I);
%    figure();
%    imshow(I)
%    title('Original Image')
    
    %Convert original image to gray image
    grayImage = rgb2gray(I);

    %Edge Detection
     edgeImage = edge(grayImage, 'sobel', 'vertical'); 
%    figure();
%    imshow(edgeImage)

    % Identify space enclosed by vertical lines
    CC = bwconncomp(edgeImage); %find connected components
    
    %Get the stats of each connected region
    stats = regionprops(CC,'Centroid','BoundingBox', 'Eccentricity', ...
        'Solidity', 'FilledArea', 'Extent', 'Euler', 'Image', 'Orientation');
 
    %Filter out unwanted bounding boxes from image
    filterIdx = [stats.FilledArea] < 20;
    filterIdx =  [stats.Eccentricity] < .995;
    filterIdx = filterIdx | [stats.Extent] > .95;
    filterIdx = filterIdx | ([stats.Orientation] > -85 & [stats.Orientation] < 85);
    stats(filterIdx) = [];
                
    %bboxes is in [x y width height]
    bboxes = vertcat(stats.BoundingBox);
    %idx = 1;
    newbboxes = zeros(2,4);
    
    %Find matching pairs of bounding box in the image. Choose best one.
    %Relax parameters with each "scale" loop run.
  for scale = 0:5
      g = 1 + scale*0.2;
      for j = 1:size(bboxes,1)
        for i = 1:size(bboxes,1)
            left = bboxes(j,1);
            top = bboxes(j,2);
            width = bboxes(j,3);
            height = bboxes(j,4);
            left2 = bboxes(i,1);
            top2 = bboxes(i,2);
            width2 = bboxes(i,3);
            height2 = bboxes(i,4);
            horizDist = left - left2;
            topDist = abs(top - top2);
            bottomDist = abs((top + height) - (top2 + height2));
            
            aspectRatio = horizDist / height;
            %abs(height - height2)
            if (height > 25 && height2 > 25)
                %if abs(height - height2) < 20
                    %abs(height - height2)
                    if topDist < 10*g && bottomDist < 10*g
                        if aspectRatio < 3.83*g && aspectRatio > 1.75/g   
                           if max(newbboxes(:,4)) <= bboxes(j, 4) && max(newbboxes(:,4)) <= bboxes(i, 4)              
                               if(newbboxes(1,4) ~= 0 && g>1)
                                    scale = 6;
                                else
                                    newbboxes(1,:) = bboxes(j,:);
                                    newbboxes(2,:) = bboxes(i,:);
                                 end
                           end
                           %idx = idx + 2;
                        end
                    end
                %end
            end
        end
      end
  end 
    
    
    %newbboxes
    
    % Convert from the [x y width height] bounding box format to the [xmin ymin
    % xmax ymax] format for convenience.
    xmin = bboxes(:,1);
    ymin = bboxes(:,2);
    xmax = xmin + bboxes(:,3) - 1;
    ymax = ymin + bboxes(:,4) - 1;
    
    BBoxes = [xmin ymin xmax-xmin+1 ymax-ymin+1];
    DrawBBoxes = insertShape(im2uint16(edgeImage),'Rectangle',BBoxes,'LineWidth',3);
    
%     figure();
%     imshow(DrawBBoxes)
%     title('Bounding Boxes Text')
    
    %Logic to convert two boxes into one big box around the plate.
    if newbboxes(1,1) < newbboxes(2,1)
        box(1,1) = newbboxes(1,1);
    else
        box(1,1) = newbboxes(2,1);
    end
    if newbboxes(1,2) < newbboxes(2,2)
        box(1,2) = newbboxes(1,2);
    else
        box(1,2) = newbboxes(2,2);
    end
    if newbboxes(1,1) - newbboxes(2,1) > 0
        box(1,3) = abs((newbboxes(1,1)+ newbboxes(1,3)) - newbboxes(2,1));
    else
        box(1,3) = abs(newbboxes(1,1) - (newbboxes(2,1) + newbboxes(2,3)));
    end
    %box(1,3) = abs(newbboxes(1,1) - newbboxes(2,1));
    box(1,4) = max(newbboxes(1,4), newbboxes(2,4));
    newImg = imcrop(I, box);
    
%      figure();
%      imshow(newImg); title('4:Cut Image');

    
    TextRecognition(newImg);

end